/*******************************************************************************
* File Name: MAX7219_BOOT.c
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the bootloader
*  communication support in the SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "MAX7219_BOOT.h"


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_BTLDR_COMM_MODE_ENABLED)

/*******************************************************************************
* Function Name: MAX7219_CyBtldrCommStart
********************************************************************************
*
* Summary:
*  Calls the CyBtldrCommStart function of the bootloader communication
*  component for the selected mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MAX7219_CyBtldrCommStart(void)
{
    #if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
        if(MAX7219_SCB_MODE_I2C_RUNTM_CFG)
        {
            MAX7219_I2CCyBtldrCommStart();
        }
        else if(MAX7219_SCB_MODE_SPI_RUNTM_CFG)
        {
            MAX7219_SpiCyBtldrCommStart();
        }
        else if(MAX7219_SCB_MODE_UART_RUNTM_CFG)
        {
            MAX7219_UartCyBtldrCommStart();
        }
        else if(MAX7219_SCB_MODE_EZI2C_RUNTM_CFG)
        {
             MAX7219_EzI2CCyBtldrCommStart();
        }
        else
        {
            /* Unknown mode */
        }
    #elif(MAX7219_SCB_MODE_I2C_CONST_CFG)
        MAX7219_I2CCyBtldrCommStart();

    #elif(MAX7219_SCB_MODE_SPI_CONST_CFG)
        MAX7219_SpiCyBtldrCommStart();

    #elif(MAX7219_SCB_MODE_UART_CONST_CFG)
        MAX7219_UartCyBtldrCommStart();

    #elif(MAX7219_SCB_MODE_EZI2C_CONST_CFG)
        MAX7219_EzI2CCyBtldrCommStart();

    #else
        /* Unknown mode */

    #endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: MAX7219_CyBtldrCommStop
********************************************************************************
*
* Summary:
*  Calls the CyBtldrCommStop function of the bootloader communication
*  component for the selected mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MAX7219_CyBtldrCommStop(void)
{
    #if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
        if(MAX7219_SCB_MODE_I2C_RUNTM_CFG)
        {
            MAX7219_I2CCyBtldrCommStop();
        }
        else if(MAX7219_SCB_MODE_SPI_RUNTM_CFG)
        {
            MAX7219_SpiCyBtldrCommStop();
        }
        else if(MAX7219_SCB_MODE_UART_RUNTM_CFG)
        {
            MAX7219_UartCyBtldrCommStop();
        }
        else if(MAX7219_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            MAX7219_EzI2CCyBtldrCommStop();
        }
        else
        {
            /* Unknown mode */
        }
    #elif(MAX7219_SCB_MODE_I2C_CONST_CFG)
        MAX7219_I2CCyBtldrCommStop();

    #elif(MAX7219_SCB_MODE_SPI_CONST_CFG)
        MAX7219_SpiCyBtldrCommStop();

    #elif(MAX7219_SCB_MODE_UART_CONST_CFG)
        MAX7219_UartCyBtldrCommStop();

    #elif(MAX7219_SCB_MODE_EZI2C_CONST_CFG)
        MAX7219_EzI2CCyBtldrCommStop();

    #else
        /* Unknown mode */

    #endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: MAX7219_CyBtldrCommReset
********************************************************************************
*
* Summary:
*  Calls the CyBtldrCommReset function of the bootloader communication
*  component for the selected mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MAX7219_CyBtldrCommReset(void)
{
    #if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
        if(MAX7219_SCB_MODE_I2C_RUNTM_CFG)
        {
            MAX7219_I2CCyBtldrCommReset();
        }
        else if(MAX7219_SCB_MODE_SPI_RUNTM_CFG)
        {
            MAX7219_SpiCyBtldrCommReset();
        }
        else if(MAX7219_SCB_MODE_UART_RUNTM_CFG)
        {
            MAX7219_UartCyBtldrCommReset();
        }
        else if(MAX7219_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            MAX7219_EzI2CCyBtldrCommReset();
        }
        else
        {
            /* Unknown mode */
        }
    #elif(MAX7219_SCB_MODE_I2C_CONST_CFG)
        MAX7219_I2CCyBtldrCommReset();

    #elif(MAX7219_SCB_MODE_SPI_CONST_CFG)
        MAX7219_SpiCyBtldrCommReset();

    #elif(MAX7219_SCB_MODE_UART_CONST_CFG)
        MAX7219_UartCyBtldrCommReset();

    #elif(MAX7219_SCB_MODE_EZI2C_CONST_CFG)
        MAX7219_EzI2CCyBtldrCommReset();

    #else
        /* Unknown mode */

    #endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: MAX7219_CyBtldrCommRead
********************************************************************************
*
* Summary:
*  Calls the CyBtldrCommRead function of the bootloader communication
*  component for the selected mode.
*
* Parameters:
*  pData:    Pointer to storage for the block of data to be read from the
*            bootloader host
*  size:     Number of bytes to be read.
*  count:    Pointer to the variable to write the number of bytes actually
*            read.
*  timeOut:  Number of units in 10 ms to wait before returning because of a
*            timeout.
*
* Return:
*  Returns CYRET_SUCCESS if no problem was encountered or returns the value
*  that best describes the problem.
*
*******************************************************************************/
cystatus MAX7219_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut)
{
    cystatus status;

    #if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
        if(MAX7219_SCB_MODE_I2C_RUNTM_CFG)
        {
            status = MAX7219_I2CCyBtldrCommRead(pData, size, count, timeOut);
        }
        else if(MAX7219_SCB_MODE_SPI_RUNTM_CFG)
        {
            status = MAX7219_SpiCyBtldrCommRead(pData, size, count, timeOut);
        }
        else if(MAX7219_SCB_MODE_UART_RUNTM_CFG)
        {
            status = MAX7219_UartCyBtldrCommRead(pData, size, count, timeOut);
        }
        else if(MAX7219_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            status = MAX7219_EzI2CCyBtldrCommRead(pData, size, count, timeOut);
        }
        else
        {
            status = CYRET_INVALID_STATE; /* Unknown mode: return status */
        }

    #elif(MAX7219_SCB_MODE_I2C_CONST_CFG)
        status = MAX7219_I2CCyBtldrCommRead(pData, size, count, timeOut);

    #elif(MAX7219_SCB_MODE_SPI_CONST_CFG)
        status = MAX7219_SpiCyBtldrCommRead(pData, size, count, timeOut);

    #elif(MAX7219_SCB_MODE_UART_CONST_CFG)
        status = MAX7219_UartCyBtldrCommRead(pData, size, count, timeOut);

    #elif(MAX7219_SCB_MODE_EZI2C_CONST_CFG)
        status = MAX7219_EzI2CCyBtldrCommRead(pData, size, count, timeOut);

    #else
        status = CYRET_INVALID_STATE; /* Unknown mode: return status */

    #endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */

    return(status);
}


/*******************************************************************************
* Function Name: MAX7219_CyBtldrCommWrite
********************************************************************************
*
* Summary:
*  Calls the CyBtldrCommWrite  function of the bootloader communication
*  component for the selected mode.
*
* Parameters:
*  pData:    Pointer to the block of data to be written to the bootloader host.
*  size:     Number of bytes to be written.
*  count:    Pointer to the variable to write the number of bytes actually
*            written.
*  timeOut:  Number of units in 10 ms to wait before returning because of a
*            timeout.
*
* Return:
*  Returns CYRET_SUCCESS if no problem was encountered or returns the value
*  that best describes the problem.
*
*******************************************************************************/
cystatus MAX7219_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut)
{
    cystatus status;

    #if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
        if(MAX7219_SCB_MODE_I2C_RUNTM_CFG)
        {
            status = MAX7219_I2CCyBtldrCommWrite(pData, size, count, timeOut);
        }
        else if(MAX7219_SCB_MODE_SPI_RUNTM_CFG)
        {
            status = MAX7219_SpiCyBtldrCommWrite(pData, size, count, timeOut);
        }
        else if(MAX7219_SCB_MODE_UART_RUNTM_CFG)
        {
            status = MAX7219_UartCyBtldrCommWrite(pData, size, count, timeOut);
        }
        else if(MAX7219_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            status = MAX7219_EzI2CCyBtldrCommWrite(pData, size, count, timeOut);
        }
        else
        {
            status = CYRET_INVALID_STATE; /* Unknown mode */
        }
    #elif(MAX7219_SCB_MODE_I2C_CONST_CFG)
        status = MAX7219_I2CCyBtldrCommWrite(pData, size, count, timeOut);

    #elif(MAX7219_SCB_MODE_SPI_CONST_CFG)
        status = MAX7219_SpiCyBtldrCommWrite(pData, size, count, timeOut);

    #elif(MAX7219_SCB_MODE_UART_CONST_CFG)
        status = MAX7219_UartCyBtldrCommWrite(pData, size, count, timeOut);

    #elif(MAX7219_SCB_MODE_EZI2C_CONST_CFG)
        status = MAX7219_EzI2CCyBtldrCommWrite(pData, size, count, timeOut);

    #else
        status = CYRET_INVALID_STATE; /* Unknown mode */

    #endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */

    return(status);
}

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_BTLDR_COMM_MODE_ENABLED) */


/* [] END OF FILE */
