/*******************************************************************************
* File Name: MAX7219_BOOT.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the bootloader
*  communication interface of SCB component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_MAX7219_H)
#define CY_SCB_BOOT_MAX7219_H

#include "MAX7219_PVT.h"

#if (MAX7219_SCB_MODE_I2C_INC)
    #include "MAX7219_I2C.h"
#endif /* (MAX7219_SCB_MODE_I2C_INC) */

#if (MAX7219_SCB_MODE_EZI2C_INC)
    #include "MAX7219_EZI2C.h"
#endif /* (MAX7219_SCB_MODE_EZI2C_INC) */

#if (MAX7219_SCB_MODE_SPI_INC || MAX7219_SCB_MODE_UART_INC)
    #include "MAX7219_SPI_UART.h"
#endif /* (MAX7219_SCB_MODE_SPI_INC || MAX7219_SCB_MODE_UART_INC) */


/***************************************
*        Function Prototypes
***************************************/

/* Bootloader communication interface enable */
#define MAX7219_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_MAX7219) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

#if (MAX7219_SCB_MODE_I2C_INC)

    #define MAX7219_I2C_BTLDR_COMM_ENABLED     (MAX7219_BTLDR_COMM_ENABLED && \
                                                            (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             MAX7219_I2C_SLAVE_CONST))

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_I2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void MAX7219_I2CCyBtldrCommStart(void);
    void MAX7219_I2CCyBtldrCommStop (void);
    void MAX7219_I2CCyBtldrCommReset(void);
    cystatus MAX7219_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus MAX7219_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Size of Read/Write buffers for I2C bootloader  */
    #define MAX7219_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
    #define MAX7219_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)
    #define MAX7219_I2C_MIN_UINT16(a, b)           ( ((uint16)(a) < (uint16) (b)) ? \
                                                                    ((uint32) (a)) : ((uint32) (b)) )
    #define MAX7219_WAIT_1_MS                      (1u)
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_I2C_BTLDR_COMM_ENABLED) */

#endif /* (MAX7219_SCB_MODE_I2C_INC) */


#if (MAX7219_SCB_MODE_EZI2C_INC)

    /* Provide EMPTY bootloader communication functions. EZI2C is NOT supported yet */
    #define MAX7219_EZI2C_BTLDR_COMM_ENABLED   (MAX7219_BTLDR_COMM_ENABLED && \
                                                         MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void MAX7219_EzI2CCyBtldrCommStart(void);
    void MAX7219_EzI2CCyBtldrCommStop (void);
    void MAX7219_EzI2CCyBtldrCommReset(void);
    cystatus MAX7219_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus MAX7219_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_EZI2C_BTLDR_COMM_ENABLED) */

#endif /* (MAX7219_SCB_MODE_EZI2C_INC) */

#if (MAX7219_SCB_MODE_SPI_INC || MAX7219_SCB_MODE_UART_INC)
    /* Provide EMPTY bootloader communication functions. SPI and UART is NOT supported yet */
    #define MAX7219_SPI_BTLDR_COMM_ENABLED     (MAX7219_BTLDR_COMM_ENABLED && \
                                                        MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)

    #define MAX7219_UART_BTLDR_COMM_ENABLED    (MAX7219_BTLDR_COMM_ENABLED && \
                                                        MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void MAX7219_SpiCyBtldrCommStart(void);
    void MAX7219_SpiCyBtldrCommStop (void);
    void MAX7219_SpiCyBtldrCommReset(void);
    cystatus MAX7219_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus MAX7219_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void MAX7219_UartCyBtldrCommStart(void);
    void MAX7219_UartCyBtldrCommStop (void);
    void MAX7219_UartCyBtldrCommReset(void);
    cystatus MAX7219_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus MAX7219_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_UART_BTLDR_COMM_ENABLED) */

#endif /* (MAX7219_SCB_MODE_SPI_INC || MAX7219_SCB_MODE_UART_INC) */

#if !defined (MAX7219_I2C_BTLDR_COMM_ENABLED)
    #define MAX7219_I2C_BTLDR_COMM_ENABLED     (0u)
#endif /* (MAX7219_I2C_BTLDR_COMM_ENABLED) */

#if !defined (MAX7219_EZI2C_BTLDR_COMM_ENABLED)
    #define MAX7219_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (MAX7219_EZI2C_BTLDR_COMM_ENABLED) */

#if !defined (MAX7219_SPI_BTLDR_COMM_ENABLED)
    #define MAX7219_SPI_BTLDR_COMM_ENABLED     (0u)
#endif /* (MAX7219_SPI_BTLDR_COMM_ENABLED) */

#if !defined (MAX7219_UART_BTLDR_COMM_ENABLED)
    #define MAX7219_UART_BTLDR_COMM_ENABLED    (0u)
#endif /* (MAX7219_UART_BTLDR_COMM_ENABLED) */

/* Bootloader enabled condition for each mode */
#define MAX7219_BTLDR_COMM_MODE_ENABLED    (MAX7219_I2C_BTLDR_COMM_ENABLED   || \
                                                     MAX7219_EZI2C_BTLDR_COMM_ENABLED || \
                                                     MAX7219_SPI_BTLDR_COMM_ENABLED   || \
                                                     MAX7219_UART_BTLDR_COMM_ENABLED)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_BTLDR_COMM_ENABLED)
    #if (MAX7219_BTLDR_COMM_MODE_ENABLED)
        /* Bootloader physical layer functions */
        void MAX7219_CyBtldrCommStart(void);
        void MAX7219_CyBtldrCommStop (void);
        void MAX7219_CyBtldrCommReset(void);
        cystatus MAX7219_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus MAX7219_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (MAX7219_BTLDR_COMM_MODE_ENABLED) */

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_MAX7219)
        #define CyBtldrCommStart    MAX7219_CyBtldrCommStart
        #define CyBtldrCommStop     MAX7219_CyBtldrCommStop
        #define CyBtldrCommReset    MAX7219_CyBtldrCommReset
        #define CyBtldrCommWrite    MAX7219_CyBtldrCommWrite
        #define CyBtldrCommRead     MAX7219_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_MAX7219) */
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (MAX7219_BTLDR_COMM_ENABLED) */

#endif /* (CY_SCB_BOOT_MAX7219_H) */

/* [] END OF FILE */
