/*******************************************************************************
* File Name: MAX7219_SPI_UART.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the SCB Component in
*  SPI and UART modes.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_MAX7219_H)
#define CY_SCB_SPI_UART_MAX7219_H

#include "MAX7219.h"


/***************************************
*   SPI Initial Parameter Constants
****************************************/

#define MAX7219_SPI_MODE                   (1u)
#define MAX7219_SPI_SUB_MODE               (0u)
#define MAX7219_SPI_CLOCK_MODE             (0u)
#define MAX7219_SPI_OVS_FACTOR             (16u)
#define MAX7219_SPI_MEDIAN_FILTER_ENABLE   (0u)
#define MAX7219_SPI_LATE_MISO_SAMPLE_ENABLE (0u)
#define MAX7219_SPI_RX_DATA_BITS_NUM       (8u)
#define MAX7219_SPI_TX_DATA_BITS_NUM       (8u)
#define MAX7219_SPI_WAKE_ENABLE            (0u)
#define MAX7219_SPI_BITS_ORDER             (1u)
#define MAX7219_SPI_TRANSFER_SEPARATION    (1u)
#define MAX7219_SPI_NUMBER_OF_SS_LINES     (0u)
#define MAX7219_SPI_RX_BUFFER_SIZE         (8u)
#define MAX7219_SPI_TX_BUFFER_SIZE         (8u)

#define MAX7219_SPI_INTERRUPT_MODE         (0u)

#define MAX7219_SPI_INTR_RX_MASK           (0u)
#define MAX7219_SPI_INTR_TX_MASK           (0u)

#define MAX7219_SPI_RX_TRIGGER_LEVEL       (7u)
#define MAX7219_SPI_TX_TRIGGER_LEVEL       (0u)

#define MAX7219_SPI_BYTE_MODE_ENABLE       (0u)
#define MAX7219_SPI_FREE_RUN_SCLK_ENABLE   (0u)
#define MAX7219_SPI_SS0_POLARITY           (0u)
#define MAX7219_SPI_SS1_POLARITY           (0u)
#define MAX7219_SPI_SS2_POLARITY           (0u)
#define MAX7219_SPI_SS3_POLARITY           (0u)


/***************************************
*   UART Initial Parameter Constants
****************************************/

#define MAX7219_UART_SUB_MODE              (0u)
#define MAX7219_UART_DIRECTION             (3u)
#define MAX7219_UART_DATA_BITS_NUM         (8u)
#define MAX7219_UART_PARITY_TYPE           (2u)
#define MAX7219_UART_STOP_BITS_NUM         (2u)
#define MAX7219_UART_OVS_FACTOR            (12u)
#define MAX7219_UART_IRDA_LOW_POWER        (0u)
#define MAX7219_UART_MEDIAN_FILTER_ENABLE  (0u)
#define MAX7219_UART_RETRY_ON_NACK         (0u)
#define MAX7219_UART_IRDA_POLARITY         (0u)
#define MAX7219_UART_DROP_ON_FRAME_ERR     (0u)
#define MAX7219_UART_DROP_ON_PARITY_ERR    (0u)
#define MAX7219_UART_WAKE_ENABLE           (0u)
#define MAX7219_UART_RX_BUFFER_SIZE        (8u)
#define MAX7219_UART_TX_BUFFER_SIZE        (8u)
#define MAX7219_UART_MP_MODE_ENABLE        (0u)
#define MAX7219_UART_MP_ACCEPT_ADDRESS     (0u)
#define MAX7219_UART_MP_RX_ADDRESS         (2u)
#define MAX7219_UART_MP_RX_ADDRESS_MASK    (255u)

#define MAX7219_UART_INTERRUPT_MODE        (0u)

#define MAX7219_UART_INTR_RX_MASK          (0u)
#define MAX7219_UART_INTR_TX_MASK          (0u)

#define MAX7219_UART_RX_TRIGGER_LEVEL      (7u)
#define MAX7219_UART_TX_TRIGGER_LEVEL      (0u)

#define MAX7219_UART_BYTE_MODE_ENABLE      (0u)
#define MAX7219_UART_CTS_ENABLE            (0u)
#define MAX7219_UART_CTS_POLARITY          (0u)
#define MAX7219_UART_RTS_POLARITY          (0u)
#define MAX7219_UART_RTS_FIFO_LEVEL        (4u)

/* SPI mode enum */
#define MAX7219_SPI_SLAVE  (0u)
#define MAX7219_SPI_MASTER (1u)

/* UART direction enum */
#define MAX7219_UART_RX    (1u)
#define MAX7219_UART_TX    (2u)
#define MAX7219_UART_TX_RX (3u)


/***************************************
*   Conditional Compilation Parameters
****************************************/

#if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)

    /* Mode */
    #define MAX7219_SPI_MASTER_CONST       (1u)

    /* Direction */
    #define MAX7219_RX_DIRECTION           (1u)
    #define MAX7219_TX_DIRECTION           (1u)
    #define MAX7219_UART_RX_DIRECTION      (1u)
    #define MAX7219_UART_TX_DIRECTION      (1u)

    /* Only external RX and TX buffer for Uncofigured mode */
    #define MAX7219_INTERNAL_RX_SW_BUFFER   (0u)
    #define MAX7219_INTERNAL_TX_SW_BUFFER   (0u)

    /* Get RX and TX buffer size */
    #define MAX7219_RX_BUFFER_SIZE (MAX7219_rxBufferSize)
    #define MAX7219_TX_BUFFER_SIZE (MAX7219_txBufferSize)

    /* Return true if buffer is provided */
    #define MAX7219_CHECK_RX_SW_BUFFER (NULL != MAX7219_rxBuffer)
    #define MAX7219_CHECK_TX_SW_BUFFER (NULL != MAX7219_txBuffer)

    /* Always provide global variables to support RX and TX buffers */
    #define MAX7219_INTERNAL_RX_SW_BUFFER_CONST    (1u)
    #define MAX7219_INTERNAL_TX_SW_BUFFER_CONST    (1u)

    /* Get wakeup enable option */
    #define MAX7219_SPI_WAKE_ENABLE_CONST  (1u)
    #define MAX7219_CHECK_SPI_WAKE_ENABLE  (0u != MAX7219_scbEnableWake)
    #define MAX7219_UART_WAKE_ENABLE_CONST (1u)

    /* SPI/UART: TX or RX FIFO size */
    #if (MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1)
        #define MAX7219_SPI_UART_FIFO_SIZE (MAX7219_FIFO_SIZE)
    #else
        #define MAX7219_SPI_UART_FIFO_SIZE (MAX7219_GET_FIFO_SIZE(MAX7219_CTRL_REG & \
                                                                                    MAX7219_CTRL_BYTE_MODE))
    #endif /* (MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1) */

#else

    /* Internal RX and TX buffer: for SPI or UART */
    #if (MAX7219_SCB_MODE_SPI_CONST_CFG)

        /* SPI Direction */
        #define MAX7219_SPI_RX_DIRECTION (1u)
        #define MAX7219_SPI_TX_DIRECTION (1u)

        /* Get FIFO size */
        #if (MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1)
            #define MAX7219_SPI_UART_FIFO_SIZE    (MAX7219_FIFO_SIZE)
        #else
            #define MAX7219_SPI_UART_FIFO_SIZE \
                                           MAX7219_GET_FIFO_SIZE(MAX7219_SPI_BYTE_MODE_ENABLE)

        #endif /* (MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1) */

        /* SPI internal RX and TX buffers */
        #define MAX7219_INTERNAL_SPI_RX_SW_BUFFER  (MAX7219_SPI_RX_BUFFER_SIZE > \
                                                                MAX7219_SPI_UART_FIFO_SIZE)
        #define MAX7219_INTERNAL_SPI_TX_SW_BUFFER  (MAX7219_SPI_TX_BUFFER_SIZE > \
                                                                MAX7219_SPI_UART_FIFO_SIZE)

        /* Internal SPI RX and TX buffer */
        #define MAX7219_INTERNAL_RX_SW_BUFFER  (MAX7219_INTERNAL_SPI_RX_SW_BUFFER)
        #define MAX7219_INTERNAL_TX_SW_BUFFER  (MAX7219_INTERNAL_SPI_TX_SW_BUFFER)

        /* Internal SPI RX and TX buffer size */
        #define MAX7219_RX_BUFFER_SIZE         (MAX7219_SPI_RX_BUFFER_SIZE + 1u)
        #define MAX7219_TX_BUFFER_SIZE         (MAX7219_SPI_TX_BUFFER_SIZE)

        /* Get wakeup enable option */
        #define MAX7219_SPI_WAKE_ENABLE_CONST  (0u != MAX7219_SPI_WAKE_ENABLE)
        #define MAX7219_UART_WAKE_ENABLE_CONST (0u)

    #else

        /* UART Direction */
        #define MAX7219_UART_RX_DIRECTION (0u != (MAX7219_UART_DIRECTION & MAX7219_UART_RX))
        #define MAX7219_UART_TX_DIRECTION (0u != (MAX7219_UART_DIRECTION & MAX7219_UART_TX))

        /* Get FIFO size */
        #if (MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1)
            #define MAX7219_SPI_UART_FIFO_SIZE    (MAX7219_FIFO_SIZE)
        #else
            #define MAX7219_SPI_UART_FIFO_SIZE \
                                           MAX7219_GET_FIFO_SIZE(MAX7219_UART_BYTE_MODE_ENABLE)
        #endif /* (MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1) */

        /* UART internal RX and TX buffers */
        #define MAX7219_INTERNAL_UART_RX_SW_BUFFER  (MAX7219_UART_RX_BUFFER_SIZE > \
                                                                MAX7219_SPI_UART_FIFO_SIZE)
        #define MAX7219_INTERNAL_UART_TX_SW_BUFFER  (MAX7219_UART_TX_BUFFER_SIZE > \
                                                                    MAX7219_SPI_UART_FIFO_SIZE)

        /* Internal UART RX and TX buffer */
        #define MAX7219_INTERNAL_RX_SW_BUFFER  (MAX7219_INTERNAL_UART_RX_SW_BUFFER)
        #define MAX7219_INTERNAL_TX_SW_BUFFER  (MAX7219_INTERNAL_UART_TX_SW_BUFFER)

        /* Internal UART RX and TX buffer size */
        #define MAX7219_RX_BUFFER_SIZE         (MAX7219_UART_RX_BUFFER_SIZE + 1u)
        #define MAX7219_TX_BUFFER_SIZE         (MAX7219_UART_TX_BUFFER_SIZE)

        /* Get wakeup enable option */
        #define MAX7219_SPI_WAKE_ENABLE_CONST  (0u)
        #define MAX7219_UART_WAKE_ENABLE_CONST (0u != MAX7219_UART_WAKE_ENABLE)

    #endif /* (MAX7219_SCB_MODE_SPI_CONST_CFG) */

    /* Mode */
    #define MAX7219_SPI_MASTER_CONST   (MAX7219_SPI_MODE == MAX7219_SPI_MASTER)

    /* Direction */
    #define MAX7219_RX_DIRECTION ((MAX7219_SCB_MODE_SPI_CONST_CFG) ? \
                                            (MAX7219_SPI_RX_DIRECTION) : (MAX7219_UART_RX_DIRECTION))

    #define MAX7219_TX_DIRECTION ((MAX7219_SCB_MODE_SPI_CONST_CFG) ? \
                                            (MAX7219_SPI_TX_DIRECTION) : (MAX7219_UART_TX_DIRECTION))

    /* Internal RX and TX buffer: for SPI or UART. Used in conditional compilation check */
    #define MAX7219_CHECK_RX_SW_BUFFER (MAX7219_INTERNAL_RX_SW_BUFFER)
    #define MAX7219_CHECK_TX_SW_BUFFER (MAX7219_INTERNAL_TX_SW_BUFFER)

    /* Provide global variables to support RX and TX buffers */
    #define MAX7219_INTERNAL_RX_SW_BUFFER_CONST    (MAX7219_INTERNAL_RX_SW_BUFFER)
    #define MAX7219_INTERNAL_TX_SW_BUFFER_CONST    (MAX7219_INTERNAL_TX_SW_BUFFER)

    /* Wakeup for SPI */
    #define MAX7219_CHECK_SPI_WAKE_ENABLE  (MAX7219_SPI_WAKE_ENABLE_CONST)

#endif /* End (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*       Type Definitions
***************************************/

/* MAX7219_SPI_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 submode;
    uint32 sclkMode;
    uint32 oversample;
    uint32 enableMedianFilter;
    uint32 enableLateSampling;
    uint32 enableWake;
    uint32 rxDataBits;
    uint32 txDataBits;
    uint32 bitOrder;
    uint32 transferSeperation;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
    uint8 enableByteMode;
    uint8 enableFreeRunSclk;
    uint8 polaritySs;
} MAX7219_SPI_INIT_STRUCT;

/* MAX7219_UART_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 direction;
    uint32 dataBits;
    uint32 parity;
    uint32 stopBits;
    uint32 oversample;
    uint32 enableIrdaLowPower;
    uint32 enableMedianFilter;
    uint32 enableRetryNack;
    uint32 enableInvertedRx;
    uint32 dropOnParityErr;
    uint32 dropOnFrameErr;
    uint32 enableWake;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableMultiproc;
    uint32 multiprocAcceptAddr;
    uint32 multiprocAddr;
    uint32 multiprocAddrMask;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
    uint8 enableByteMode;
    uint8 enableCts;
    uint8 ctsPolarity;
    uint8 rtsRxFifoLevel;
    uint8 rtsPolarity;
} MAX7219_UART_INIT_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

/* SPI specific functions */
#if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
    void MAX7219_SpiInit(const MAX7219_SPI_INIT_STRUCT *config);
#endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(MAX7219_SCB_MODE_SPI_INC)
    #define MAX7219_SpiIsBusBusy() ((uint32) (0u != (MAX7219_SPI_STATUS_REG & \
                                                              MAX7219_SPI_STATUS_BUS_BUSY)))

    #if (MAX7219_SPI_MASTER_CONST)
        void MAX7219_SpiSetActiveSlaveSelect(uint32 slaveSelect);
    #endif /*(MAX7219_SPI_MASTER_CONST) */

    #if !(MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1)
        void MAX7219_SpiSetSlaveSelectPolarity(uint32 slaveSelect, uint32 polarity);
    #endif /* !(MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1) */
#endif /* (MAX7219_SCB_MODE_SPI_INC) */

/* UART specific functions */
#if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
    void MAX7219_UartInit(const MAX7219_UART_INIT_STRUCT *config);
#endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(MAX7219_SCB_MODE_UART_INC)
    void MAX7219_UartSetRxAddress(uint32 address);
    void MAX7219_UartSetRxAddressMask(uint32 addressMask);

    /* UART RX direction APIs */
    #if(MAX7219_UART_RX_DIRECTION)
        uint32 MAX7219_UartGetChar(void);
        uint32 MAX7219_UartGetByte(void);

        #if !(MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1)
            /* UART APIs for Flow Control */
            void MAX7219_UartSetRtsPolarity(uint32 polarity);
            void MAX7219_UartSetRtsFifoLevel(uint32 level);
        #endif /* !(MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1) */
    #endif /* (MAX7219_UART_RX_DIRECTION) */

    /* UART TX direction APIs */
    #if(MAX7219_UART_TX_DIRECTION)
        #define MAX7219_UartPutChar(ch)    MAX7219_SpiUartWriteTxData((uint32)(ch))
        void MAX7219_UartPutString(const char8 string[]);
        void MAX7219_UartPutCRLF(uint32 txDataByte);

        #if !(MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1)
            /* UART APIs for Flow Control */
            void MAX7219_UartEnableCts(void);
            void MAX7219_UartDisableCts(void);
            void MAX7219_UartSetCtsPolarity(uint32 polarity);
        #endif /* !(MAX7219_CY_SCBIP_V0 || MAX7219_CY_SCBIP_V1) */
    #endif /* (MAX7219_UART_TX_DIRECTION) */
#endif /* (MAX7219_SCB_MODE_UART_INC) */

/* Common APIs RX direction */
#if(MAX7219_RX_DIRECTION)
    uint32 MAX7219_SpiUartReadRxData(void);
    uint32 MAX7219_SpiUartGetRxBufferSize(void);
    void   MAX7219_SpiUartClearRxBuffer(void);
#endif /* (MAX7219_RX_DIRECTION) */

/* Common APIs TX direction */
#if(MAX7219_TX_DIRECTION)
    void   MAX7219_SpiUartWriteTxData(uint32 txData);
    void   MAX7219_SpiUartPutArray(const uint8 wrBuf[], uint32 count);
    void   MAX7219_SpiUartClearTxBuffer(void);
    uint32 MAX7219_SpiUartGetTxBufferSize(void);
#endif /* (MAX7219_TX_DIRECTION) */

CY_ISR_PROTO(MAX7219_SPI_UART_ISR);

#if(MAX7219_UART_RX_WAKEUP_IRQ)
    CY_ISR_PROTO(MAX7219_UART_WAKEUP_ISR);
#endif /* (MAX7219_UART_RX_WAKEUP_IRQ) */


/***************************************
*     Buffer Access Macro Definitions
***************************************/

#if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
    /* RX direction */
    void   MAX7219_PutWordInRxBuffer  (uint32 idx, uint32 rxDataByte);
    uint32 MAX7219_GetWordFromRxBuffer(uint32 idx);

    /* TX direction */
    void   MAX7219_PutWordInTxBuffer  (uint32 idx, uint32 txDataByte);
    uint32 MAX7219_GetWordFromTxBuffer(uint32 idx);

#else
    /* RX direction */
    #if(MAX7219_INTERNAL_RX_SW_BUFFER_CONST)
        #define MAX7219_PutWordInRxBuffer(idx, rxDataByte) \
                do{                                                 \
                    MAX7219_rxBufferInternal[(idx)] = ((uint8) (rxDataByte)); \
                }while(0)

        #define MAX7219_GetWordFromRxBuffer(idx) MAX7219_rxBufferInternal[(idx)]

    #endif /* (MAX7219_INTERNAL_RX_SW_BUFFER_CONST) */

    /* TX direction */
    #if(MAX7219_INTERNAL_TX_SW_BUFFER_CONST)
        #define MAX7219_PutWordInTxBuffer(idx, txDataByte) \
                    do{                                             \
                        MAX7219_txBufferInternal[(idx)] = ((uint8) (txDataByte)); \
                    }while(0)

        #define MAX7219_GetWordFromTxBuffer(idx) MAX7219_txBufferInternal[(idx)]

    #endif /* (MAX7219_INTERNAL_TX_SW_BUFFER_CONST) */

#endif /* (MAX7219_TX_SW_BUFFER_ENABLE) */


/***************************************
*         SPI API Constants
***************************************/

/* SPI sub mode enum */
#define MAX7219_SPI_MODE_MOTOROLA      (0x00u)
#define MAX7219_SPI_MODE_TI_COINCIDES  (0x01u)
#define MAX7219_SPI_MODE_TI_PRECEDES   (0x11u)
#define MAX7219_SPI_MODE_NATIONAL      (0x02u)
#define MAX7219_SPI_MODE_MASK          (0x03u)
#define MAX7219_SPI_MODE_TI_PRECEDES_MASK  (0x10u)
#define MAX7219_SPI_MODE_NS_MICROWIRE  (MAX7219_SPI_MODE_NATIONAL)

/* SPI phase and polarity mode enum */
#define MAX7219_SPI_SCLK_CPHA0_CPOL0   (0x00u)
#define MAX7219_SPI_SCLK_CPHA0_CPOL1   (0x02u)
#define MAX7219_SPI_SCLK_CPHA1_CPOL0   (0x01u)
#define MAX7219_SPI_SCLK_CPHA1_CPOL1   (0x03u)

/* SPI bits order enum */
#define MAX7219_BITS_ORDER_LSB_FIRST   (0u)
#define MAX7219_BITS_ORDER_MSB_FIRST   (1u)

/* SPI transfer separation enum */
#define MAX7219_SPI_TRANSFER_SEPARATED     (0u)
#define MAX7219_SPI_TRANSFER_CONTINUOUS    (1u)

/* SPI slave select constants */
#define MAX7219_SPI_SLAVE_SELECT0    (MAX7219_SCB__SS0_POSISTION)
#define MAX7219_SPI_SLAVE_SELECT1    (MAX7219_SCB__SS1_POSISTION)
#define MAX7219_SPI_SLAVE_SELECT2    (MAX7219_SCB__SS2_POSISTION)
#define MAX7219_SPI_SLAVE_SELECT3    (MAX7219_SCB__SS3_POSISTION)

/* SPI slave select polarity settings */
#define MAX7219_SPI_SS_ACTIVE_LOW  (0u)
#define MAX7219_SPI_SS_ACTIVE_HIGH (1u)


/***************************************
*         UART API Constants
***************************************/

/* UART sub-modes enum */
#define MAX7219_UART_MODE_STD          (0u)
#define MAX7219_UART_MODE_SMARTCARD    (1u)
#define MAX7219_UART_MODE_IRDA         (2u)

/* UART direction enum */
#define MAX7219_UART_RX    (1u)
#define MAX7219_UART_TX    (2u)
#define MAX7219_UART_TX_RX (3u)

/* UART parity enum */
#define MAX7219_UART_PARITY_EVEN   (0u)
#define MAX7219_UART_PARITY_ODD    (1u)
#define MAX7219_UART_PARITY_NONE   (2u)

/* UART stop bits enum */
#define MAX7219_UART_STOP_BITS_1   (2u)
#define MAX7219_UART_STOP_BITS_1_5 (3u)
#define MAX7219_UART_STOP_BITS_2   (4u)

/* UART IrDA low power OVS enum */
#define MAX7219_UART_IRDA_LP_OVS16     (16u)
#define MAX7219_UART_IRDA_LP_OVS32     (32u)
#define MAX7219_UART_IRDA_LP_OVS48     (48u)
#define MAX7219_UART_IRDA_LP_OVS96     (96u)
#define MAX7219_UART_IRDA_LP_OVS192    (192u)
#define MAX7219_UART_IRDA_LP_OVS768    (768u)
#define MAX7219_UART_IRDA_LP_OVS1536   (1536u)

/* Uart MP: mark (address) and space (data) bit definitions */
#define MAX7219_UART_MP_MARK       (0x100u)
#define MAX7219_UART_MP_SPACE      (0x000u)

/* UART CTS/RTS polarity settings */
#define MAX7219_UART_CTS_ACTIVE_LOW    (0u)
#define MAX7219_UART_CTS_ACTIVE_HIGH   (1u)
#define MAX7219_UART_RTS_ACTIVE_LOW    (0u)
#define MAX7219_UART_RTS_ACTIVE_HIGH   (1u)

/* Sources of RX errors */
#define MAX7219_INTR_RX_ERR        (MAX7219_INTR_RX_OVERFLOW    | \
                                             MAX7219_INTR_RX_UNDERFLOW   | \
                                             MAX7219_INTR_RX_FRAME_ERROR | \
                                             MAX7219_INTR_RX_PARITY_ERROR)

/* Shifted INTR_RX_ERR defines ONLY for MAX7219_UartGetByte() */
#define MAX7219_UART_RX_OVERFLOW       (MAX7219_INTR_RX_OVERFLOW << 8u)
#define MAX7219_UART_RX_UNDERFLOW      (MAX7219_INTR_RX_UNDERFLOW << 8u)
#define MAX7219_UART_RX_FRAME_ERROR    (MAX7219_INTR_RX_FRAME_ERROR << 8u)
#define MAX7219_UART_RX_PARITY_ERROR   (MAX7219_INTR_RX_PARITY_ERROR << 8u)
#define MAX7219_UART_RX_ERROR_MASK     (MAX7219_UART_RX_OVERFLOW    | \
                                                 MAX7219_UART_RX_UNDERFLOW   | \
                                                 MAX7219_UART_RX_FRAME_ERROR | \
                                                 MAX7219_UART_RX_PARITY_ERROR)


/***************************************
*     Vars with External Linkage
***************************************/

#if(MAX7219_SCB_MODE_UNCONFIG_CONST_CFG)
    extern const MAX7219_SPI_INIT_STRUCT  MAX7219_configSpi;
    extern const MAX7219_UART_INIT_STRUCT MAX7219_configUart;
#endif /* (MAX7219_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*    Specific SPI Macro Definitions
***************************************/

#define MAX7219_GET_SPI_INTR_SLAVE_MASK(sourceMask)  ((sourceMask) & MAX7219_INTR_SLAVE_SPI_BUS_ERROR)
#define MAX7219_GET_SPI_INTR_MASTER_MASK(sourceMask) ((sourceMask) & MAX7219_INTR_MASTER_SPI_DONE)
#define MAX7219_GET_SPI_INTR_RX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~MAX7219_INTR_SLAVE_SPI_BUS_ERROR)

#define MAX7219_GET_SPI_INTR_TX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~MAX7219_INTR_MASTER_SPI_DONE)


/***************************************
*    Specific UART Macro Definitions
***************************************/

#define MAX7219_UART_GET_CTRL_OVS_IRDA_LP(oversample) \
        ((MAX7219_UART_IRDA_LP_OVS16   == (oversample)) ? MAX7219_CTRL_OVS_IRDA_LP_OVS16 : \
         ((MAX7219_UART_IRDA_LP_OVS32   == (oversample)) ? MAX7219_CTRL_OVS_IRDA_LP_OVS32 : \
          ((MAX7219_UART_IRDA_LP_OVS48   == (oversample)) ? MAX7219_CTRL_OVS_IRDA_LP_OVS48 : \
           ((MAX7219_UART_IRDA_LP_OVS96   == (oversample)) ? MAX7219_CTRL_OVS_IRDA_LP_OVS96 : \
            ((MAX7219_UART_IRDA_LP_OVS192  == (oversample)) ? MAX7219_CTRL_OVS_IRDA_LP_OVS192 : \
             ((MAX7219_UART_IRDA_LP_OVS768  == (oversample)) ? MAX7219_CTRL_OVS_IRDA_LP_OVS768 : \
              ((MAX7219_UART_IRDA_LP_OVS1536 == (oversample)) ? MAX7219_CTRL_OVS_IRDA_LP_OVS1536 : \
                                                                          MAX7219_CTRL_OVS_IRDA_LP_OVS16)))))))

#define MAX7219_GET_UART_RX_CTRL_ENABLED(direction) ((0u != (MAX7219_UART_RX & (direction))) ? \
                                                                     (MAX7219_RX_CTRL_ENABLED) : (0u))

#define MAX7219_GET_UART_TX_CTRL_ENABLED(direction) ((0u != (MAX7219_UART_TX & (direction))) ? \
                                                                     (MAX7219_TX_CTRL_ENABLED) : (0u))


/***************************************
*        SPI Register Settings
***************************************/

#define MAX7219_CTRL_SPI      (MAX7219_CTRL_MODE_SPI)
#define MAX7219_SPI_RX_CTRL   (MAX7219_RX_CTRL_ENABLED)
#define MAX7219_SPI_TX_CTRL   (MAX7219_TX_CTRL_ENABLED)


/***************************************
*       SPI Init Register Settings
***************************************/

#define MAX7219_SPI_SS_POLARITY \
             (((uint32) MAX7219_SPI_SS0_POLARITY << MAX7219_SPI_SLAVE_SELECT0) | \
              ((uint32) MAX7219_SPI_SS1_POLARITY << MAX7219_SPI_SLAVE_SELECT1) | \
              ((uint32) MAX7219_SPI_SS2_POLARITY << MAX7219_SPI_SLAVE_SELECT2) | \
              ((uint32) MAX7219_SPI_SS3_POLARITY << MAX7219_SPI_SLAVE_SELECT3))

#if(MAX7219_SCB_MODE_SPI_CONST_CFG)

    /* SPI Configuration */
    #define MAX7219_SPI_DEFAULT_CTRL \
                    (MAX7219_GET_CTRL_OVS(MAX7219_SPI_OVS_FACTOR) | \
                     MAX7219_GET_CTRL_BYTE_MODE (MAX7219_SPI_BYTE_MODE_ENABLE) | \
                     MAX7219_GET_CTRL_EC_AM_MODE(MAX7219_SPI_WAKE_ENABLE)      | \
                     MAX7219_CTRL_SPI)

    #define MAX7219_SPI_DEFAULT_SPI_CTRL \
                    (MAX7219_GET_SPI_CTRL_CONTINUOUS    (MAX7219_SPI_TRANSFER_SEPARATION)       | \
                     MAX7219_GET_SPI_CTRL_SELECT_PRECEDE(MAX7219_SPI_SUB_MODE &                   \
                                                                  MAX7219_SPI_MODE_TI_PRECEDES_MASK)     | \
                     MAX7219_GET_SPI_CTRL_SCLK_MODE     (MAX7219_SPI_CLOCK_MODE)                | \
                     MAX7219_GET_SPI_CTRL_LATE_MISO_SAMPLE(MAX7219_SPI_LATE_MISO_SAMPLE_ENABLE) | \
                     MAX7219_GET_SPI_CTRL_SCLK_CONTINUOUS(MAX7219_SPI_FREE_RUN_SCLK_ENABLE)     | \
                     MAX7219_GET_SPI_CTRL_SSEL_POLARITY (MAX7219_SPI_SS_POLARITY)               | \
                     MAX7219_GET_SPI_CTRL_SUB_MODE      (MAX7219_SPI_SUB_MODE)                  | \
                     MAX7219_GET_SPI_CTRL_MASTER_MODE   (MAX7219_SPI_MODE))

    /* RX direction */
    #define MAX7219_SPI_DEFAULT_RX_CTRL \
                    (MAX7219_GET_RX_CTRL_DATA_WIDTH(MAX7219_SPI_RX_DATA_BITS_NUM)     | \
                     MAX7219_GET_RX_CTRL_BIT_ORDER (MAX7219_SPI_BITS_ORDER)           | \
                     MAX7219_GET_RX_CTRL_MEDIAN    (MAX7219_SPI_MEDIAN_FILTER_ENABLE) | \
                     MAX7219_SPI_RX_CTRL)

    #define MAX7219_SPI_DEFAULT_RX_FIFO_CTRL \
                    MAX7219_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(MAX7219_SPI_RX_TRIGGER_LEVEL)

    /* TX direction */
    #define MAX7219_SPI_DEFAULT_TX_CTRL \
                    (MAX7219_GET_TX_CTRL_DATA_WIDTH(MAX7219_SPI_TX_DATA_BITS_NUM) | \
                     MAX7219_GET_TX_CTRL_BIT_ORDER (MAX7219_SPI_BITS_ORDER)       | \
                     MAX7219_SPI_TX_CTRL)

    #define MAX7219_SPI_DEFAULT_TX_FIFO_CTRL \
                    MAX7219_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(MAX7219_SPI_TX_TRIGGER_LEVEL)

    /* Interrupt sources */
    #define MAX7219_SPI_DEFAULT_INTR_SPI_EC_MASK   (MAX7219_NO_INTR_SOURCES)

    #define MAX7219_SPI_DEFAULT_INTR_I2C_EC_MASK   (MAX7219_NO_INTR_SOURCES)
    #define MAX7219_SPI_DEFAULT_INTR_SLAVE_MASK \
                    (MAX7219_SPI_INTR_RX_MASK & MAX7219_INTR_SLAVE_SPI_BUS_ERROR)

    #define MAX7219_SPI_DEFAULT_INTR_MASTER_MASK \
                    (MAX7219_SPI_INTR_TX_MASK & MAX7219_INTR_MASTER_SPI_DONE)

    #define MAX7219_SPI_DEFAULT_INTR_RX_MASK \
                    (MAX7219_SPI_INTR_RX_MASK & (uint32) ~MAX7219_INTR_SLAVE_SPI_BUS_ERROR)

    #define MAX7219_SPI_DEFAULT_INTR_TX_MASK \
                    (MAX7219_SPI_INTR_TX_MASK & (uint32) ~MAX7219_INTR_MASTER_SPI_DONE)

#endif /* (MAX7219_SCB_MODE_SPI_CONST_CFG) */


/***************************************
*        UART Register Settings
***************************************/

#define MAX7219_CTRL_UART      (MAX7219_CTRL_MODE_UART)
#define MAX7219_UART_RX_CTRL   (MAX7219_RX_CTRL_LSB_FIRST) /* LSB for UART goes first */
#define MAX7219_UART_TX_CTRL   (MAX7219_TX_CTRL_LSB_FIRST) /* LSB for UART goes first */


/***************************************
*      UART Init Register Settings
***************************************/

#if(MAX7219_SCB_MODE_UART_CONST_CFG)

    /* UART configuration */
    #if(MAX7219_UART_MODE_IRDA == MAX7219_UART_SUB_MODE)

        #define MAX7219_DEFAULT_CTRL_OVS   ((0u != MAX7219_UART_IRDA_LOW_POWER) ?              \
                                (MAX7219_UART_GET_CTRL_OVS_IRDA_LP(MAX7219_UART_OVS_FACTOR)) : \
                                (MAX7219_CTRL_OVS_IRDA_OVS16))

    #else

        #define MAX7219_DEFAULT_CTRL_OVS   MAX7219_GET_CTRL_OVS(MAX7219_UART_OVS_FACTOR)

    #endif /* (MAX7219_UART_MODE_IRDA == MAX7219_UART_SUB_MODE) */

    #define MAX7219_UART_DEFAULT_CTRL \
                                (MAX7219_GET_CTRL_BYTE_MODE  (MAX7219_UART_BYTE_MODE_ENABLE)  | \
                                 MAX7219_GET_CTRL_ADDR_ACCEPT(MAX7219_UART_MP_ACCEPT_ADDRESS) | \
                                 MAX7219_DEFAULT_CTRL_OVS                                              | \
                                 MAX7219_CTRL_UART)

    #define MAX7219_UART_DEFAULT_UART_CTRL \
                                    (MAX7219_GET_UART_CTRL_MODE(MAX7219_UART_SUB_MODE))

    /* RX direction */
    #define MAX7219_UART_DEFAULT_RX_CTRL_PARITY \
                                ((MAX7219_UART_PARITY_NONE != MAX7219_UART_PARITY_TYPE) ?      \
                                  (MAX7219_GET_UART_RX_CTRL_PARITY(MAX7219_UART_PARITY_TYPE) | \
                                   MAX7219_UART_RX_CTRL_PARITY_ENABLED) : (0u))

    #define MAX7219_UART_DEFAULT_UART_RX_CTRL \
                    (MAX7219_GET_UART_RX_CTRL_MODE(MAX7219_UART_STOP_BITS_NUM)                    | \
                     MAX7219_GET_UART_RX_CTRL_POLARITY(MAX7219_UART_IRDA_POLARITY)                | \
                     MAX7219_GET_UART_RX_CTRL_MP_MODE(MAX7219_UART_MP_MODE_ENABLE)                | \
                     MAX7219_GET_UART_RX_CTRL_DROP_ON_PARITY_ERR(MAX7219_UART_DROP_ON_PARITY_ERR) | \
                     MAX7219_GET_UART_RX_CTRL_DROP_ON_FRAME_ERR(MAX7219_UART_DROP_ON_FRAME_ERR)   | \
                     MAX7219_UART_DEFAULT_RX_CTRL_PARITY)

    #define MAX7219_UART_DEFAULT_RX_CTRL \
                                (MAX7219_GET_RX_CTRL_DATA_WIDTH(MAX7219_UART_DATA_BITS_NUM)        | \
                                 MAX7219_GET_RX_CTRL_MEDIAN    (MAX7219_UART_MEDIAN_FILTER_ENABLE) | \
                                 MAX7219_GET_UART_RX_CTRL_ENABLED(MAX7219_UART_DIRECTION))

    #define MAX7219_UART_DEFAULT_RX_FIFO_CTRL \
                                MAX7219_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(MAX7219_UART_RX_TRIGGER_LEVEL)

    #define MAX7219_UART_DEFAULT_RX_MATCH_REG  ((0u != MAX7219_UART_MP_MODE_ENABLE) ?          \
                                (MAX7219_GET_RX_MATCH_ADDR(MAX7219_UART_MP_RX_ADDRESS) | \
                                 MAX7219_GET_RX_MATCH_MASK(MAX7219_UART_MP_RX_ADDRESS_MASK)) : (0u))

    /* TX direction */
    #define MAX7219_UART_DEFAULT_TX_CTRL_PARITY (MAX7219_UART_DEFAULT_RX_CTRL_PARITY)

    #define MAX7219_UART_DEFAULT_UART_TX_CTRL \
                                (MAX7219_GET_UART_TX_CTRL_MODE(MAX7219_UART_STOP_BITS_NUM)       | \
                                 MAX7219_GET_UART_TX_CTRL_RETRY_NACK(MAX7219_UART_RETRY_ON_NACK) | \
                                 MAX7219_UART_DEFAULT_TX_CTRL_PARITY)

    #define MAX7219_UART_DEFAULT_TX_CTRL \
                                (MAX7219_GET_TX_CTRL_DATA_WIDTH(MAX7219_UART_DATA_BITS_NUM) | \
                                 MAX7219_GET_UART_TX_CTRL_ENABLED(MAX7219_UART_DIRECTION))

    #define MAX7219_UART_DEFAULT_TX_FIFO_CTRL \
                                MAX7219_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(MAX7219_UART_TX_TRIGGER_LEVEL)

    #define MAX7219_UART_DEFAULT_FLOW_CTRL \
                        (MAX7219_GET_UART_FLOW_CTRL_TRIGGER_LEVEL(MAX7219_UART_RTS_FIFO_LEVEL) | \
                         MAX7219_GET_UART_FLOW_CTRL_RTS_POLARITY (MAX7219_UART_RTS_POLARITY)   | \
                         MAX7219_GET_UART_FLOW_CTRL_CTS_POLARITY (MAX7219_UART_CTS_POLARITY)   | \
                         MAX7219_GET_UART_FLOW_CTRL_CTS_ENABLE   (MAX7219_UART_CTS_ENABLE))

    /* Interrupt sources */
    #define MAX7219_UART_DEFAULT_INTR_I2C_EC_MASK  (MAX7219_NO_INTR_SOURCES)
    #define MAX7219_UART_DEFAULT_INTR_SPI_EC_MASK  (MAX7219_NO_INTR_SOURCES)
    #define MAX7219_UART_DEFAULT_INTR_SLAVE_MASK   (MAX7219_NO_INTR_SOURCES)
    #define MAX7219_UART_DEFAULT_INTR_MASTER_MASK  (MAX7219_NO_INTR_SOURCES)
    #define MAX7219_UART_DEFAULT_INTR_RX_MASK      (MAX7219_UART_INTR_RX_MASK)
    #define MAX7219_UART_DEFAULT_INTR_TX_MASK      (MAX7219_UART_INTR_TX_MASK)

#endif /* (MAX7219_SCB_MODE_UART_CONST_CFG) */


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

#define MAX7219_SPIM_ACTIVE_SS0    (MAX7219_SPI_SLAVE_SELECT0)
#define MAX7219_SPIM_ACTIVE_SS1    (MAX7219_SPI_SLAVE_SELECT1)
#define MAX7219_SPIM_ACTIVE_SS2    (MAX7219_SPI_SLAVE_SELECT2)
#define MAX7219_SPIM_ACTIVE_SS3    (MAX7219_SPI_SLAVE_SELECT3)

#endif /* CY_SCB_SPI_UART_MAX7219_H */


/* [] END OF FILE */
