/*******************************************************************************
* File Name: MAX7219_SPI_UART_PVT.h
* Version 2.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_MAX7219_H)
#define CY_SCB_SPI_UART_PVT_MAX7219_H

#include "MAX7219_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if(MAX7219_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  MAX7219_rxBufferHead;
    extern volatile uint32  MAX7219_rxBufferTail;
    extern volatile uint8   MAX7219_rxBufferOverflow;
#endif /* (MAX7219_INTERNAL_RX_SW_BUFFER_CONST) */

#if(MAX7219_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  MAX7219_txBufferHead;
    extern volatile uint32  MAX7219_txBufferTail;
#endif /* (MAX7219_INTERNAL_TX_SW_BUFFER_CONST) */

#if(MAX7219_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 MAX7219_rxBufferInternal[MAX7219_RX_BUFFER_SIZE];
#endif /* (MAX7219_INTERNAL_RX_SW_BUFFER) */

#if(MAX7219_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 MAX7219_txBufferInternal[MAX7219_TX_BUFFER_SIZE];
#endif /* (MAX7219_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

#if(MAX7219_SCB_MODE_SPI_CONST_CFG)
    void MAX7219_SpiInit(void);
#endif /* (MAX7219_SCB_MODE_SPI_CONST_CFG) */

#if(MAX7219_SPI_WAKE_ENABLE_CONST)
    void MAX7219_SpiSaveConfig(void);
    void MAX7219_SpiRestoreConfig(void);
#endif /* (MAX7219_SPI_WAKE_ENABLE_CONST) */

#if(MAX7219_SCB_MODE_UART_CONST_CFG)
    void MAX7219_UartInit(void);
#endif /* (MAX7219_SCB_MODE_UART_CONST_CFG) */

#if(MAX7219_UART_WAKE_ENABLE_CONST)
    void MAX7219_UartSaveConfig(void);
    void MAX7219_UartRestoreConfig(void);
    #define MAX7219_UartStop() \
        do{                             \
            MAX7219_UART_RX_CTRL_REG &= ~MAX7219_UART_RX_CTRL_SKIP_START; \
        }while(0)
#else
        #define MAX7219_UartStop() do{ /* Does nothing */ }while(0)

#endif /* (MAX7219_UART_WAKE_ENABLE_CONST) */

/* Interrupt processing */
#define MAX7219_SpiUartEnableIntRx(intSourceMask)  MAX7219_SetRxInterruptMode(intSourceMask)
#define MAX7219_SpiUartEnableIntTx(intSourceMask)  MAX7219_SetTxInterruptMode(intSourceMask)
uint32  MAX7219_SpiUartDisableIntRx(void);
uint32  MAX7219_SpiUartDisableIntTx(void);


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in MAX7219_SetPins() */
#define MAX7219_UART_RX_PIN_ENABLE    (MAX7219_UART_RX)
#define MAX7219_UART_TX_PIN_ENABLE    (MAX7219_UART_TX)

/* UART RTS and CTS position to be used in  MAX7219_SetPins() */
#define MAX7219_UART_RTS_PIN_ENABLE    (0x10u)
#define MAX7219_UART_CTS_PIN_ENABLE    (0x20u)

#endif /* (CY_SCB_SPI_UART_PVT_MAX7219_H) */


/* [] END OF FILE */
